@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '5.1'; # VERSION
+our $VERSION = '5.2'; # VERSION
 
 use strict;
 use warnings;
@@ -775,7 +775,7 @@ sub es_node_stats {
     push @cmd, join(',', @nodes) if @nodes;
     push @cmd, 'stats';
 
-    return es_request(join('/',@cmd), { uri_param => {all => 'true', human => 'true'} });
+    return es_request(join('/',@cmd));
 }
 
 
@@ -802,7 +802,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 5.1
+version 5.2
 
 =head1 SYNOPSIS
 
