@@ -1,7 +1,7 @@
 # ABSTRACT: Fix version issues to support all the things
 package App::ElasticSearch::Utilities::VersionHacks;
 
-our $VERSION = '5.1'; # VERSION
+our $VERSION = '5.2'; # VERSION
 use strict;
 use warnings;
 
@@ -34,12 +34,9 @@ const my %SIMPLE => (
         'v2.0'  => '_optimize',
     },
     '_status' => {
-        default => '_status',
-        'v2.0'  => '_stats',
-        'v2.1'  => '_stats',
-        'v2.2'  => '_stats',
-        'v2.3'  => '_stats',
-        'v5.0'  => '_stats',
+        default => '_stats',
+        'v1.0'  => '_status',
+        'v1.1'  => '_status',
     }
 );
 my %CALLBACKS = (
@@ -166,7 +163,7 @@ App::ElasticSearch::Utilities::VersionHacks - Fix version issues to support all
 
 =head1 VERSION
 
-version 5.1
+version 5.2
 
 =head1 AUTHOR
 
